Index: gm/rebaseline_server/static/loader.js |
=================================================================== |
--- gm/rebaseline_server/static/loader.js (revision 11507) |
+++ gm/rebaseline_server/static/loader.js (working copy) |
@@ -1,7 +1,7 @@ |
/* |
* Loader: |
* Reads GM result reports written out by results_loader.py, and imports |
* their data into $scope.results . |
*/ |
var Loader = angular.module( |
'Loader', |
@@ -12,8 +12,10 @@ |
function($scope, $http) { |
$http.get("/results/all").then( |
function(response) { |
- $scope.results = response.data; |
+ $scope.categories = response.data.categories; |
+ $scope.testData = response.data.testData; |
$scope.sortColumn = 'test'; |
+ $scope.showResultsOfType = 'failed'; |
} |
); |
} |
@@ -1,7 +1,7 @@ |
/* |
* Loader: |
- * Reads GM result reports written out by results_loader.py, and imports |
- * their data into $scope.results . |
+ * Reads GM result reports written out by results.py, and imports |
+ * them into $scope.categories and $scope.testData . |
*/ |
var Loader = angular.module( |